/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.samza.operators.triggers;


import java.io.Serializable;
import org.apache.samza.annotation.InterfaceStability;

/**
 * Marker interface for all triggers. The firing of a trigger indicates the completion of a window pane.
 *
 * <p> Use the {@link Triggers} APIs to create a {@link Trigger}.
 *
 * @param <M> the type of the incoming message
 */
@InterfaceStability.Unstable
public interface Trigger<M> extends Serializable {

}
